You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2019/08/10 21:26:31 UTC

[commons-vfs] branch master updated: Javadoc fixes.

This is an automated email from the ASF dual-hosted git repository.

ggregory pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-vfs.git


The following commit(s) were added to refs/heads/master by this push:
     new 1ffa1df  Javadoc fixes.
1ffa1df is described below

commit 1ffa1dfeeeb4c8e6a2db2acf1e6b0efffec528a5
Author: Gary Gregory <ga...@gmail.com>
AuthorDate: Sat Aug 10 17:26:28 2019 -0400

    Javadoc fixes.
---
 commons-vfs2/src/main/java/org/apache/commons/vfs2/FileContent.java | 3 ---
 commons-vfs2/src/main/java/org/apache/commons/vfs2/FilesCache.java  | 6 +++---
 .../main/java/org/apache/commons/vfs2/impl/VirtualFileSystem.java   | 2 +-
 .../org/apache/commons/vfs2/provider/LayeredFileNameParser.java     | 6 +++---
 .../org/apache/commons/vfs2/provider/bzip2/Bzip2FileObject.java     | 2 +-
 .../java/org/apache/commons/vfs2/provider/gzip/GzipFileObject.java  | 2 +-
 .../org/apache/commons/vfs2/provider/url/UrlFileNameParser.java     | 2 +-
 .../main/java/org/apache/commons/vfs2/tasks/AbstractSyncTask.java   | 2 +-
 .../src/main/java/org/apache/commons/vfs2/util/FileObjectUtils.java | 2 +-
 src/changes/changes.xml                                             | 3 +++
 10 files changed, 15 insertions(+), 15 deletions(-)

diff --git a/commons-vfs2/src/main/java/org/apache/commons/vfs2/FileContent.java b/commons-vfs2/src/main/java/org/apache/commons/vfs2/FileContent.java
index 1e05055..170d9b8 100644
--- a/commons-vfs2/src/main/java/org/apache/commons/vfs2/FileContent.java
+++ b/commons-vfs2/src/main/java/org/apache/commons/vfs2/FileContent.java
@@ -119,7 +119,6 @@ public interface FileContent extends Closeable {
     /**
      * Returns the content of a file as a byte array.
      *
-     * @param file The file to get the content of.
      * @return The content as a byte array.
      * @throws IOException if the file content cannot be accessed.
      * @since 2.4
@@ -273,7 +272,6 @@ public interface FileContent extends Closeable {
     /**
      * Returns the content of a file as a String.
      *
-     * @param file The file to get the content of.
      * @param charset The file character set, may be null.
      * @return The content as a byte array.
      * @throws IOException if the file content cannot be accessed.
@@ -286,7 +284,6 @@ public interface FileContent extends Closeable {
     /**
      * Returns the content of a file as a String.
      *
-     * @param file The file to get the content of.
      * @param charset The file character set, may be null.
      * @return The content as a byte array.
      * @throws IOException if the file content cannot be accessed.
diff --git a/commons-vfs2/src/main/java/org/apache/commons/vfs2/FilesCache.java b/commons-vfs2/src/main/java/org/apache/commons/vfs2/FilesCache.java
index e01b8d8..8f37d6d 100644
--- a/commons-vfs2/src/main/java/org/apache/commons/vfs2/FilesCache.java
+++ b/commons-vfs2/src/main/java/org/apache/commons/vfs2/FilesCache.java
@@ -39,11 +39,11 @@ public interface FilesCache {
     /**
      * Retrieves a FileObject from the cache by name.
      *
-     * @param file system The FileSystem.
-     * @param name the name
+     * @param fileSystem The FileSystem.
+     * @param fileName the name
      * @return the file object or null if file is not cached
      */
-    FileObject getFile(final FileSystem fileSystem, final FileName name);
+    FileObject getFile(final FileSystem fileSystem, final FileName fileName);
 
     /**
      * Purges the entries corresponding to the FileSystem.
diff --git a/commons-vfs2/src/main/java/org/apache/commons/vfs2/impl/VirtualFileSystem.java b/commons-vfs2/src/main/java/org/apache/commons/vfs2/impl/VirtualFileSystem.java
index a59b7fe..d7765a9 100644
--- a/commons-vfs2/src/main/java/org/apache/commons/vfs2/impl/VirtualFileSystem.java
+++ b/commons-vfs2/src/main/java/org/apache/commons/vfs2/impl/VirtualFileSystem.java
@@ -35,7 +35,7 @@ import org.apache.commons.vfs2.provider.DelegateFileObject;
  * A logical file system, made up of set of junctions, or links, to files from other file systems.
  * <p>
  * TODO - Handle nested junctions.
- * <p>
+ * </p>
  */
 public class VirtualFileSystem extends AbstractFileSystem {
     private final Map<FileName, FileObject> junctions = new HashMap<>();
diff --git a/commons-vfs2/src/main/java/org/apache/commons/vfs2/provider/bzip2/Bzip2FileObject.java b/commons-vfs2/src/main/java/org/apache/commons/vfs2/provider/bzip2/Bzip2FileObject.java
index ca0c814..44c2909 100644
--- a/commons-vfs2/src/main/java/org/apache/commons/vfs2/provider/bzip2/Bzip2FileObject.java
+++ b/commons-vfs2/src/main/java/org/apache/commons/vfs2/provider/bzip2/Bzip2FileObject.java
@@ -37,7 +37,7 @@ public class Bzip2FileObject extends CompressedFileFileObject<Bzip2FileSystem> {
      *
      * @param name Abstract file name.
      * @param container My container.
-     * @param container My file system.
+     * @param fs My file system.
      *
      * @deprecated Use {@link #Bzip2FileObject(AbstractFileName, FileObject, Bzip2FileSystem)} instead.
      */
diff --git a/commons-vfs2/src/main/java/org/apache/commons/vfs2/provider/gzip/GzipFileObject.java b/commons-vfs2/src/main/java/org/apache/commons/vfs2/provider/gzip/GzipFileObject.java
index 13d96c8..498ff0e 100644
--- a/commons-vfs2/src/main/java/org/apache/commons/vfs2/provider/gzip/GzipFileObject.java
+++ b/commons-vfs2/src/main/java/org/apache/commons/vfs2/provider/gzip/GzipFileObject.java
@@ -36,7 +36,7 @@ public class GzipFileObject extends CompressedFileFileObject<GzipFileSystem> {
      *
      * @param name Abstract file name.
      * @param container My container.
-     * @param container My file system.
+     * @param fs My file system.
      *
      * @deprecated Use {@link #GzipFileObject(AbstractFileName, FileObject, GzipFileSystem)} instead.
      */
diff --git a/commons-vfs2/src/main/java/org/apache/commons/vfs2/provider/url/UrlFileNameParser.java b/commons-vfs2/src/main/java/org/apache/commons/vfs2/provider/url/UrlFileNameParser.java
index 08f9a3f..309573c 100644
--- a/commons-vfs2/src/main/java/org/apache/commons/vfs2/provider/url/UrlFileNameParser.java
+++ b/commons-vfs2/src/main/java/org/apache/commons/vfs2/provider/url/UrlFileNameParser.java
@@ -87,7 +87,7 @@ public class UrlFileNameParser extends AbstractFileNameParser {
     /**
      * This method counts the slashes after the scheme.
      *
-     * @param file name The file name.
+     * @param fileName The file name.
      * @return number of slashes
      */
     protected int countSlashes(final String fileName) {
diff --git a/commons-vfs2/src/main/java/org/apache/commons/vfs2/tasks/AbstractSyncTask.java b/commons-vfs2/src/main/java/org/apache/commons/vfs2/tasks/AbstractSyncTask.java
index 3bd95ac..094e8bf 100644
--- a/commons-vfs2/src/main/java/org/apache/commons/vfs2/tasks/AbstractSyncTask.java
+++ b/commons-vfs2/src/main/java/org/apache/commons/vfs2/tasks/AbstractSyncTask.java
@@ -48,7 +48,7 @@ import org.apache.tools.ant.Project;
  * <li>TOOD - Allow selector, mapper, filters, etc to be specified.</li>
  * <li>TODO - Handle source/dest directories as well.</li>
  * <li>TODO - Allow selector to be specified for choosing which dest files to sync.</li>
- * <ul>
+ * </ul>
  */
 public abstract class AbstractSyncTask extends VfsTask {
     private final ArrayList<SourceInfo> srcFiles = new ArrayList<>();
diff --git a/commons-vfs2/src/main/java/org/apache/commons/vfs2/util/FileObjectUtils.java b/commons-vfs2/src/main/java/org/apache/commons/vfs2/util/FileObjectUtils.java
index 115af51..a311048 100644
--- a/commons-vfs2/src/main/java/org/apache/commons/vfs2/util/FileObjectUtils.java
+++ b/commons-vfs2/src/main/java/org/apache/commons/vfs2/util/FileObjectUtils.java
@@ -129,7 +129,7 @@ public final class FileObjectUtils {
      *
      * @param fileObject the file to read
      * @return a new {@link Properties}.
-     * @throws IOException
+     * @throws IOException On error getting this file's content.
      * @throws FileSystemException On error getting this file's content.
      * @throws IOException On error getting this file's content.
      * @since 2.4
diff --git a/src/changes/changes.xml b/src/changes/changes.xml
index e227c91..d755c2a 100644
--- a/src/changes/changes.xml
+++ b/src/changes/changes.xml
@@ -56,6 +56,9 @@ The <action> type attribute can be add,update,fix,remove.
       <action issue="VFS-724" dev="ggregory" type="fix" due-to="William R, Gary Gregory">
         FileContent#getByteArray() throws IllegalArgumentException: Buffer size <= 0 when file size is 0.
       </action>
+      <action                 dev="ggregory" type="fix" due-to="Gary Gregory">
+        Javadoc fixes.
+      </action>
     </release>
     <release version="2.4" date="2019-07-12" description="New features and bug fix release.">
       <action issue="VFS-690" dev="ggregory" type="add">
diff --git a/commons-vfs2/src/main/java/org/apache/commons/vfs2/provider/LayeredFileNameParser.java b/commons-vfs2/src/main/java/org/apache/commons/vfs2/provider/LayeredFileNameParser.java
index 67b690f..7f11d57 100644
--- a/commons-vfs2/src/main/java/org/apache/commons/vfs2/provider/LayeredFileNameParser.java
+++ b/commons-vfs2/src/main/java/org/apache/commons/vfs2/provider/LayeredFileNameParser.java
@@ -54,13 +54,13 @@ public class LayeredFileNameParser extends AbstractFileNameParser {
      * Parses the base and name into a FileName.
      *
      * @param context The component context.
      * @param base The base FileName.
      * @param file name The target file name.
      * @return The constructed FileName.
      * @throws FileSystemException if an error occurs.
      */
     @Override
-    public FileName parseUri(final VfsComponentContext context, final FileName base, final String fileName)
+    public FileName parseUri(final VfsComponentContext context, final FileName baseFileName, final String fileName)
             throws FileSystemException {
         final StringBuilder name = new StringBuilder();
 
@@ -54,13 +54,13 @@ public class LayeredFileNameParser extends AbstractFileNameParser {
      *
      * @param context The component context.
-     * @param base The base FileName.
-     * @param file name The target file name.
+     * @param baseFileName The base FileName.
+     * @param fileName name The target file name.
      * @return The constructed FileName.
      * @throws FileSystemException if an error occurs.